#!/usr/bin/env bash

# Ce script construit l'image Docker pour le frontend de FabriqueDoc.
# Il est conçu pour fonctionner sur Windows (avec Git Bash ou WSL), macOS et Linux.

# Fonction pour vérifier si une commande existe
command_exists() {
    command -v "$1" >/dev/null 2>&1
}

# Vérifier si Docker est installé
if ! command_exists docker; then
    echo "Erreur : Docker n'est pas installé. Veuillez installer Docker et réessayer."
    exit 1
fi

# Définir les variables
IMAGE_NAME="local/fabriquedoc-frontend"
DOCKERFILE_PATH="."

# Afficher un message de début
echo "Début de la construction de l'image Docker pour FabriqueDoc Frontend..."

# Construire l'image Docker
if docker build -t "$IMAGE_NAME" "$DOCKERFILE_PATH"; then
    echo "L'image Docker a été construite avec succès."
    echo "Nom de l'image : $IMAGE_NAME"
else
    echo "Erreur lors de la construction de l'image Docker."
    exit 1
fi

# Afficher des informations sur l'image construite
echo "Informations sur l'image construite :"
docker image inspect "$IMAGE_NAME" --format='ID: {{.Id}}\nTaille: {{.Size}}\nDate de création: {{.Created}}'

echo "Construction terminée."